%* sasdrugdev_creategroup                                                                        *;
%*                                                                                               *;
%* Creates a group in the specified organization, project, or analysis.                          *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_CREATEGROUP(SDD_PATH=sdd-path, SDD_GROUP=sdd-group-name                           *;
%* <, SDD_DESCRIPTION=sdd-description>);                                                         *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the context object (organization, project, or        *;
%*            analysis) where the group is to be created.                                        *;
%* @param sdd_group - required - the name of the group to create.                                *;
%* @param sdd_description - optional- the description for the group being created.               *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%*                                                                                               *;

%macro sasdrugdev_creategroup(
  sdd_path=,
  sdd_group=,
  sdd_description=
  ) /des='Create a group in the specified context.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/GroupService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticVoidMethod("create", "%bquote(&sdd_path)", "%bquote(&sdd_group)", "%bquote(&sdd_description)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
    logMsg=" The group &sdd_group was created in &sdd_path.." ;
    if (returnCode ne 0) then
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Cannot create group &sdd_group in &sdd_path.." ;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _sddMsg_= " message ;
    put logMsgPrefix " _sddRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);

  run;

%mend sasdrugdev_creategroup ;
