%* sasdrugdev_deleteuser                                                                         *;
%*                                                                                               *;
%* Deletes a user account from the system.                                                       *;
%*                                                                                               *;
%* Users that have logged in are not eligible for deletion and can only be deactivated.          *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_DELETEUSER(SDD_USERID=sdd-userid);                                                *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_userid - required - the user ID of the account being deleted.                      *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.3                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-10-30 initial coding                                                            *;
%*                                                                                               *;

%macro sasdrugdev_deleteuser(
  sdd_userid=
  ) /des='Delete a user account from the system.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/UserService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticVoidMethod("delete", "%bquote(&sdd_userid)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
    logMsg=" * The user &sdd_userid was deleted.";
    if (returnCode ne 0) then
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Cannot delete user &sdd_userid.";
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _sddMsg_= " message ;
    put logMsgPrefix " _sddRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);

  run;

%mend sasdrugdev_deleteuser;
