%* sasdrugdev_disableversioning                                                                  *;
%*                                                                                               *;
%* Disables versioning on a SAS Drug Development repository file.                                *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_DISABLEVERSIONING(SDD_PATH=sdd-path <, SDD_COMMENT=sdd-comment>);                 *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the file within the SAS Drug Development repository  *;
%*            to be set to unversioned.                                                          *;
%* @param sdd_comment - optional - a note associated with the action of disabling versioning.    *;
%*            The value is visible through the Audit Trail.                                      *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.4                                                                                    *;
%* @exposure internal                                                                            *;
%*                                                                                               *;
%* @history 2014-04-07 initial coding                                                            *;
%*                                                                                               *;

%macro sasdrugdev_disableversioning(
  sdd_path=,
  sdd_comment=
  ) /des='Disable versioning on a SAS Drug Development repository file.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/RepositoryService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticVoidMethod("disableVersioning", "%bquote(&sdd_path)", "%bquote(&sdd_comment)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode ne 0) then
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Unable to turn versioning off for the file: &sdd_path.." ;
    end;
    else
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      logMsg=" Disabled file versioning: &sdd_path..";
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _sddMsg_= " message ;
    put logMsgPrefix " _sddRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);

  run;

%mend sasdrugdev_disableversioning;
