%* sasdrugdev_resetpassword                                                                      *;
%*                                                                                               *;
%* Reset the password for a user in the system.  This action requires the logged on user to have *;
%* the administrative privilege PRIVILEGE_MANAGE_USER_ACCOUNTS.  Once the password has been      *;
%* successfully reset, the user can immediately log on with the new password, but they will be   *;
%* forced to change their password immediately so the password remains unique to the user.       *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_RESETPASSWORD(SDD_USERID=sdd-userid, SDD_NEWPASSWORD=sdd-password);               *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_userid - required - the user ID of the account to reset.                           *;
%* @param sdd_newpassword - required - the new temporary password.                               *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.3                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-11-04 initial coding                                                            *;
%*                                                                                               *;

%macro sasdrugdev_resetpassword(
  sdd_userid=,
  sdd_newpassword=
  ) /des='Reset the password for an account in the system.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/UserService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *:
    %***********************************;
    srv.callStaticVoidMethod("resetPassword", "%bquote(&sdd_userid)", "%bquote(&sdd_newpassword)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode eq 0) then
    do;
      logMsgPrefix="NOTE: SAS Drug Development Macro: * ";
      logMsg=" The password for the account &sdd_userid was successfully reset." ;
    end;
      else
    do;
      logMsgPrefix="ERR%str(OR): SAS Drug Development Macro:";
      logMsg=" Unable to reset the password for the account &sdd_userid.." ;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _sddMsg_= " message ;
    put logMsgPrefix " _sddRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_sddRC_", returnCode);
    call symputx("_sddMsg_", message);

  run;

%mend sasdrugdev_resetpassword;
